@@ -26,9 +26,7 @@ import time
 from typing import TYPE_CHECKING, Any, TypeVar, cast
 
 from bleak.backends.device import BLEDevice
-from bleak.backends.service import BleakGATTServiceCollection
 from bleak.exc import BleakError
-from bleak_retry_connector import ble_device_has_changed
 
 from aiohomekit.exceptions import (
     AccessoryDisconnectedError,
@@ -136,10 +134,6 @@ class BlePairing(AbstractPairing):
 
         super().__init__(controller, pairing_data)
 
-        self._cached_services: BleakGATTServiceCollection | None = (
-            client.services if client else None
-        )
-
         self._last_seen = time.monotonic() if description else NEVER_TIME
 
         # Encryption
@@ -218,31 +212,7 @@ class BlePairing(AbstractPairing):
 
     def _async_ble_device_update(self, device: BLEDevice) -> None:
         """Update the BLE device."""
-        original_device = self.device
         self.device = device
-        if not original_device or not ble_device_has_changed(original_device, device):
-            return
-        original_path: str | None = None
-        new_path: str | None = None
-        if (
-            isinstance(original_device.details, dict)
-            and isinstance(device.details, dict)
-            and "path" in original_device.details
-            and "path" in device.details
-        ):
-            original_path = original_device.details["path"]
-            new_path = device.details["path"]
-        logger.debug(
-            "%s: BLE device changed from %s (%s) [rssi:%s] to %s (%s) [rssi:%s]; closing connection",
-            self.name,
-            original_device.address,
-            original_path,
-            original_device.rssi,
-            device.address,
-            new_path,
-            device.rssi,
-        )
-        async_create_task(self.close_after_operation(clear_cached_services=True))
 
     def _async_description_update(
         self, description: HomeKitAdvertisement | None
@@ -324,10 +294,9 @@ class BlePairing(AbstractPairing):
                 self.device,
                 self.name,
                 self._async_disconnected,
-                cached_services=self._cached_services,
+                use_services_cache=True,
                 ble_device_callback=lambda: self.device,
             )
-            self._cached_services = self.client.services
             logger.debug(
                 "%s: Connected, processing subscriptions: %s; rssi=%s",
                 self.name,
@@ -486,17 +455,15 @@ class BlePairing(AbstractPairing):
         return accessories
 
     @operation_lock
-    async def close_after_operation(self, clear_cached_services: bool = False) -> None:
+    async def close_after_operation(self) -> None:
         """Close the client after an operation."""
-        await self.close(clear_cached_services)
+        await self.close()
 
-    async def close(self, clear_cached_services: bool = False) -> None:
+    async def close(self) -> None:
         async with self._connection_lock:
-            await self._close_while_locked(clear_cached_services)
+            await self._close_while_locked()
 
-    async def _close_while_locked(self, clear_cached_services: bool = False):
-        if clear_cached_services:
-            self._cached_services = None
+    async def _close_while_locked(self) -> None:
         if not self.client or not self.client.is_connected:
             return
         try:
