@@ -35,10 +35,6 @@ class CoAPPairing(ZeroconfPairing):
     def __init__(
         self, controller: AbstractController, pairing_data: AbstractPairingData
     ) -> None:
-        super().__init__(controller)
-
-        self.id = pairing_data["AccessoryPairingID"]
-
         self.connection = CoAPHomeKitConnection(
             self, pairing_data["AccessoryIP"], pairing_data["AccessoryPort"]
         )
@@ -46,6 +42,8 @@ class CoAPPairing(ZeroconfPairing):
         self.connection_lock = asyncio.Condition()
         self.pairing_data = pairing_data
 
+        super().__init__(controller, pairing_data)
+
     def _async_endpoint_changed(self) -> None:
         """The IP/Port has changed, so close connection if active then reconnect."""
         async_create_task(self.connection.reconnect_soon())
@@ -64,6 +62,13 @@ class CoAPPairing(ZeroconfPairing):
         """The transport used for the connection."""
         return Transport.COAP
 
+    @property
+    def name(self) -> str:
+        """Return the name of the pairing with the address."""
+        if self.description:
+            return f"{self.description.name} [{self.connection.address}] (id={self.id})"
+        return f"[{self.connection.address}] (id={self.id})"
+
     @property
     def poll_interval(self) -> timedelta:
         """Returns how often the device should be polled."""
@@ -152,6 +157,7 @@ class CoAPPairing(ZeroconfPairing):
         self._accessories_state = AccessoriesState(
             Accessories.from_list(accessories), self.config_num or 0
         )
+        self._update_accessories_state_cache()
         return accessories
 
     async def _process_config_changed(self, config_num: int) -> None:
@@ -165,6 +171,12 @@ class CoAPPairing(ZeroconfPairing):
         )
         self._callback_and_save_config_changed(config_num)
 
+    async def _process_disconnected_events(self):
+        """Process any events that happened while we were disconnected.
+
+        We don't disconnect in COAP so there is no need to do anything here.
+        """
+
     async def async_populate_accessories_state(
         self, force_update: bool = False
     ) -> bool:
